package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````V"$```````!``````````)BQ````
M`````````$``.``)`$``&@`9``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````;`````````!L``````````0`````````!````
M!0```````````````````````````````````,B;````````R)L`````````
M``$```````$````&````6*L```````!8JP$``````%BK`0``````*`4`````
M``!0%0```````````0```````@````8```!HJP```````&BK`0``````:*L!
M```````@`@```````"`"````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M````7)0```````!<E````````%R4````````#`$````````,`0````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````%BK````````6*L!``````!8JP$`
M`````*@$````````J`0````````!`````````"]L:6(O;&0M;&EN=7@M86%R
M8V@V-"YS;RXQ```$````%`````,```!'3E4`."IC:!MY9MT7R_,B0-1K%V>5
M;"`$````$`````$```!'3E4```````,````'`````````!$```!+````!```
M``@````A$!``!<`$A"@"$`6`AD"$@@D`!`D@!(B(H!!%N@`""$L```!,````
M3P```%,```!4````7````%T```!>````8````&$```!C````9````&4```!F
M````:0```````````````:\TZ&[%WQ_.WD<M:W^:?"[%F[9V5#R4(/_D#M5D
MU'S9<5@<XD?&`4+ZUX>L2^/`NN.2?%COEWG"Y3\L^J%L8+,!BV]K"4/69Z_,
M9D)%U>R)!W#3#13BGMK-XYXS8MOM%8PES`TZEPM_J9R;OMI7&^"G`@IK&IY0
MH^#[20`````````````````````````````````````#``L`N!L`````````
M```````````````#`!8``+`!`````````````````$0"```2````````````
M`````````````+L"```2`````````````````````````!0"```2````````
M`````````````````!L"```2`````````````````````````*T"```2````
M`````````````````````+T!```2``````````````````````````$````@
M`````````````````````````&P"```2`````````````````````````(0"
M```2`````````````````````````)X"```B````````````````````````
M`'T"```2`````````````````````````&0"```2````````````````````
M`````'8"```1`````````````````````````$4!```2````````````````
M`````````.T"```2`````````````````````````'0````2````````````
M`````````````-P````2``````````````````````````8"```2````````
M`````````````````&P!```2`````````````````````````-$````1````
M`````````````````````$L"```2`````````````````````````#<!```2
M`````````````````````````+,````1``````````````````````````4!
M```2`````````````````````````,(!```2````````````````````````
M`-$"```2`````````````````````````"("```2````````````````````
M`````',!```2`````````````````````````)L!```2````````````````
M`````````&`!```2`````````````````````````*,!```2````````````
M`````````````/$!```2``````````````````````````T"```2````````
M`````````````````,H!```2`````````````````````````-,!```2````
M`````````````````````+<!```2`````````````````````````!,!```2
M`````````````````````````!T````@`````````````````````````/\"
M```1`````````````````````````.0"```A````````````````````````
M`/D!```2`````````````````````````,,"```2````````````````````
M`````%0````2`````````````````````````#8"```2````````````````
M`````````,H"```2`````````````````````````)(#```2````````````
M`````````````#`"```2`````````````````````````(,````2````````
M`````````````````(\````2`````````````````````````"P!```2````
M`````````````````````%D"```2`````````````````````````/(````2
M`````````````````````````.$````2`````````````````````````$8`
M```2`````````````````````````)0"```2````````````````````````
M`.8````2`````````````````````````%4!```2````````````````````
M`````,`````2`````````````````````````(T"```2````````````````
M`````````&,````2`````````````````````````(4!```2````````````
M`````````````/\!```2`````````````````````````.,"```1````````
M`````````````````.4"```1`````````````````````````'X!```2````
M`````````````````````*0````2`````````````````````````",!```2
M`````````````````````````"D"```2`````````````````````````"P`
M```@`````````````````````````(H!```2````````````````````````
M`.0!```2`````````````````````````.L!```2````````````````````
M`````*\#```0`!<`J,`!`````````````````)L#```2``T`0#\```````!0
M`0```````-,#```2``T`D#4````````X!P```````-X"```2``T`L!\`````
M```H`@```````&$#```2``T`$"P````````$`````````'(#```0`!<`@+`!
M`````````````````&\$```2``T`%"P````````H`@```````*4$```2``T`
MT#P```````!H`@```````%L$```0`!<`@+`!`````````````````+H#```2
M``T`0"X````````H`````````.`#```2``T`<%$````````8`0```````/@#
M```1``\`X%0````````$`````````#<$```0`!<`J,`!````````````````
M`#P$```0`!<`J,`!`````````````````&<$```2``T`]"H````````X````
M`````'P$```2``T`9#0````````L`0```````(X$```2``T`M#,```````"0
M`````````.L#```0`!8``+`!`````````````````,<#```2``T`<"X`````
M```<`````````*<#```0`!8`@+`!`````````````````"T$```1`!8`>+`!
M```````(`````````%$#```2``T`L%0````````$`````````!T$```2``T`
M,%0```````!\`````````/$#```2``T`V"$``````````````````)P$```2
M``T`%%$```````!4`````````.T#```@`!8``+`!`````````````````(`#
M```2``T`1#0````````@`````````*X#```0`!<`J,`!````````````````
M``<$```2``T`,"L```````#@`````````%$$```2``T`D%(```````"4`0``
M`````$0$```2``T`D"X````````D!0````````!?251-7V1E<F5G:7-T97)4
M34-L;VYE5&%B;&4`7U]G;6]N7W-T87)T7U\`7TE435]R96=I<W1E<E1-0VQO
M;F5486)L90!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F
M;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A
M:U]N;V-O;G1E>'0`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?
M;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C
M:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T7T1Y
M;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A
M;&QO8P!O<&5N-C0`<F5A9`!?7V5R<FYO7VQO8V%T:6]N`&QS965K-C0`<'1H
M<F5A9%]G971S<&5C:69I8P!C;&]S90!E>&ET`'-T<FYC;7``8VQO<V5D:7(`
M7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!A8F]R=`!M
M96UC:'(`9V5T<&ED`'-T<F1U<`!S=')T;VL`<W1R;&5N`&UE;7-E=`!S=')S
M='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC<'D`7U]S=')N8W!Y7V-H:P!?
M7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T`'-T9&5R<@!G971U:60`<F5A
M9&QI;FL`<W1R8VAR`')E861D:7(V-`!?7V-X85]F:6YA;&EZ90!?7W-P<FEN
M=&9?8VAK`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I
M;@!?7V5N=FER;VX`7U]R96=I<W1E<E]A=&9O<FL`7U]S=&%C:U]C:&M?9W5A
M<F0`;&EB<&5R;"YS;RXU+C,R`&QI8G!T:')E860N<V\N,`!L:6)C+G-O+C8`
M;&0M;&EN=7@M86%R8V@V-"YS;RXQ`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R
M<F5N=%]E>&5C`%]?8G-S7W-T87)T7U\`9V5T7W5S97)N86UE7V9R;VU?9V5T
M<'=U:60`<&%R7V-L96%N=7``7V5D871A`%]?8G-S7V5N9%]?`'!A<E]B87-E
M;F%M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`<VAA7W5P9&%T90!?7V1A
M=&%?<W1A<G0`7TE/7W-T9&EN7W5S960`<&%R7V-U<G)E;G1?97AE8U]P<F]C
M`%]?;&EB8U]C<W5?:6YI=`!M>5]P87)?<&P`7V5N9`!?7V5N9%]?`'!A<E]I
M;FET7V5N=@!S:&%?9FEN86P`7U]B<W-?<W1A<G0`>'-?:6YI=`!P87)?9FEN
M9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!S:&%?:6YI
M=`!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXQ-P`````````"``(`
M`@`"``(``@````(``@`"``(``@`"`````@```````@`"`````@`````````"
M``(``@````,````#``(``@`"``(``P``````!``"``(``@````(``@`"``(`
M`````````@````(````"``````````(````#``(``@`"``,```````(````#
M``(``@`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``````````$``0`[`P``$````"````"7
MD98&```$`+L$`````````0`!`"$#```0````(````)>1E@8```,`NP0`````
M```!``$`,0,``!``````````EY&6!@```@"[!````````%BK`0```````P0`
M``````#P(@```````&"K`0```````P0```````"@(@```````(BO`0``````
M`P0```````"P5````````-"O`0```````P0````````P5````````."O`0``
M`````P0```````"P'P````````BP`0```````P0````````(L`$``````!BP
M`0```````P0```````#H5````````""P`0```````P0```````#P5```````
M`#"P`0```````P0```````#X5````````#BP`0```````P0````````(50``
M`````$"P`0```````P0````````050```````$BP`0```````P0````````8
M50```````%"P`0```````P0````````@50```````&"P`0```````P0`````
M```H50```````&BP`0```````P0````````P50```````'BP`0```````P0`
M``````"H6````````)"O`0```````00```D``````````````)BO`0``````
M`00```P``````````````*"O`0```````00```\``````````````*BO`0``
M`````00``!```````````````+"O`0```````00``!8``````````````+BO
M`0```````00``!D``````````````,"O`0```````00``"@`````````````
M`,BO`0```````00``"D``````````````-BO`0```````00``#8`````````
M`````.BO`0```````00``#X``````````````/"O`0```````00``$(`````
M`````````/BO`0```````00``$<``````````````*"M`0```````@0```,`
M`````````````*BM`0```````@0```0``````````````+"M`0```````@0`
M``4``````````````+BM`0```````@0```8``````````````,"M`0``````
M`@0```<``````````````,BM`0```````@0```@``````````````-"M`0``
M`````@0```H``````````````-BM`0```````@0```L``````````````."M
M`0```````@0```P``````````````.BM`0```````@0```T`````````````
M`/"M`0```````@0```X``````````````/BM`0```````@0``!$`````````
M``````"N`0```````@0``!(```````````````BN`0```````@0``!,`````
M`````````!"N`0```````@0``!0``````````````!BN`0```````@0``!4`
M`````````````""N`0```````@0``!<``````````````"BN`0```````@0`
M`!@``````````````#"N`0```````@0``!H``````````````#BN`0``````
M`@0``!L``````````````$"N`0```````@0``!P``````````````$BN`0``
M`````@0``!T``````````````%"N`0```````@0``!X``````````````%BN
M`0```````@0``!\``````````````&"N`0```````@0``"``````````````
M`&BN`0```````@0``"$``````````````'"N`0```````@0``"(`````````
M`````'BN`0```````@0``",``````````````("N`0```````@0``"0`````
M`````````(BN`0```````@0``"4``````````````)"N`0```````@0``"8`
M`````````````)BN`0```````@0``"<``````````````*"N`0```````@0`
M`"@``````````````*BN`0```````@0``"L``````````````+"N`0``````
M`@0``"P``````````````+BN`0```````@0``"T``````````````,"N`0``
M`````@0``"X``````````````,BN`0```````@0``"\``````````````-"N
M`0```````@0``#```````````````-BN`0```````@0``#$`````````````
M`."N`0```````@0``#(``````````````.BN`0```````@0``#,`````````
M`````/"N`0```````@0``#0``````````````/BN`0```````@0``#4`````
M``````````"O`0```````@0``#<```````````````BO`0```````@0``#@`
M`````````````!"O`0```````@0``#D``````````````!BO`0```````@0`
M`#H``````````````""O`0```````@0``#L``````````````"BO`0``````
M`@0``#P``````````````#"O`0```````@0``#T``````````````#BO`0``
M`````@0``#\``````````````$"O`0```````@0``$```````````````$BO
M`0```````@0``$,``````````````%"O`0```````@0``$0`````````````
M`%BO`0```````@0``$4``````````````&"O`0```````@0``$8`````````
M`````&BO`0```````@0``$@``````````````'"O`0```````@0``$D`````
M`````````'BO`0```````@0``$H``````````````/U[OZG]`P"1E`$`E/U[
MP:C``U_6`````/![OZG0``"P$<Y&^1!B-I$@`A_6'R`#U1\@`]4?(`/5T```
ML!'21OD0@C:1(`(?UM```+`1UD;Y$*(VD2`"'];0``"P$=I&^1#"-I$@`A_6
MT```L!'>1OD0XC:1(`(?UM```+`1XD;Y$`(WD2`"'];0``"P$>9&^1`B-Y$@
M`A_6T```L!'J1OD00C>1(`(?UM```+`1[D;Y$&(WD2`"'];0``"P$?)&^1""
M-Y$@`A_6T```L!'V1OD0HC>1(`(?UM```+`1^D;Y$,(WD2`"'];0``"P$?Y&
M^1#B-Y$@`A_6T```L!$"1_D0`CB1(`(?UM```+`1!D?Y$"(XD2`"'];0``"P
M$0I'^1!".)$@`A_6T```L!$.1_D08CB1(`(?UM```+`1$D?Y$((XD2`"'];0
M``"P$19'^1"B.)$@`A_6T```L!$:1_D0PCB1(`(?UM```+`1'D?Y$.(XD2`"
M'];0``"P$2)'^1`".9$@`A_6T```L!$F1_D0(CF1(`(?UM```+`1*D?Y$$(Y
MD2`"'];0``"P$2Y'^1!B.9$@`A_6T```L!$R1_D0@CF1(`(?UM```+`1-D?Y
M$*(YD2`"'];0``"P$3I'^1#".9$@`A_6T```L!$^1_D0XCF1(`(?UM```+`1
M0D?Y$`(ZD2`"'];0``"P$49'^1`B.I$@`A_6T```L!%*1_D00CJ1(`(?UM``
M`+`13D?Y$&(ZD2`"'];0``"P$5)'^1"".I$@`A_6T```L!%61_D0HCJ1(`(?
MUM```+`16D?Y$,(ZD2`"'];0``"P$5Y'^1#B.I$@`A_6T```L!%B1_D0`CN1
M(`(?UM```+`19D?Y$"([D2`"'];0``"P$6I'^1!".Y$@`A_6T```L!%N1_D0
M8CN1(`(?UM```+`1<D?Y$(([D2`"'];0``"P$79'^1"B.Y$@`A_6T```L!%Z
M1_D0PCN1(`(?UM```+`1?D?Y$.([D2`"'];0``"P$8)'^1`"/)$@`A_6T```
ML!&&1_D0(CR1(`(?UM```+`1BD?Y$$(\D2`"'];0``"P$8Y'^1!B/)$@`A_6
MT```L!&21_D0@CR1(`(?UM```+`1ED?Y$*(\D2`"'];0``"P$9I'^1#"/)$@
M`A_6T```L!&>1_D0XCR1(`(?UM```+`1HD?Y$`(]D2`"'];0``"P$:9'^1`B
M/9$@`A_6T```L!&J1_D00CV1(`(?UM```+`1KD?Y$&(]D2`"'];0``"P$;)'
M^1""/9$@`A_6T```L!&V1_D0HCV1(`(?UM```+`1ND?Y$,(]D2`"'];0``"P
M$;Y'^1#B/9$@`A_6_7NZJ<,``+#]`P"18^1'^?-3`:GU6P*IXH<#J>+C`)'A
M`P&1X$\`N>`S`9%D`$#YY"\`^00`@-*.__^7P```L,(``+``]$?Y0NQ'^>$#
M`JHP#0"4P```D`#<1_D``$`Y(`H`--,``+#4``"0E-I'^8`"0+E7__^7`FA2
M.4(`'S(":!(Y@`)`N5+__Y?A`P"JXD]`N4`0`!%4#``1(FA2.0!\?9-"```R
M(F@2.47__Y?C`P"JYB-`^<```+!B(@*1Y4]`N00\0/D!``#PQP!`^2%@(I$`
M``#P`(`BD6<$`*E#!`#Y9``!J;\$`'%-"0!4(0"`TA\@`]4@#``1Q'AA^"$$
M`)%DV"#XOP`!:VS__U2E#``1I7Q]DW4B`I%_:"7XX@,4*@$``)`$`(#2(0`J
MD:`.0/F#__^7]`,`*L`$`#1U(@*1]E,!D:`.0/D!__^7````\.$#%JH`@!B1
M?0``E"`$`+1S(@*18`Y`^>G^_Y=H__^7P```D`#D1_GA+T#Y`@!`^2$``NL"
M`(#2P00`5.`#%"KS4T&I]5M"J?U[QJC``U_6__[_E],``+!B(@*10`P`^4`#
M`+34``"0T?[_EX#:1_D``$"Y`O__EQ\D*3FG__\7H`Y`^7;__Y?T`P`JV/__
M%Z`*0/E@``"T:0<`E-W__Q?A`Q:J````\`#`%I%4``"4H`H`^>#Z_[1A!P"4
MU?__%P4$@-+`__\7(`"`4IS^_Y?[_O^7'0"`TAX`@-+E`P"JX0-`^>(C`)'F
M`P"1P```D`#P1_G#``"08^A'^<0``)"$Q$?YRO[_E_W^_Y?```"0`.!'^4``
M`+3U_O\7P`-?UA\@`]4?(`/5'R`#U<```+````*1P0``L"$``I$_``#KP```
M5,$``)`AR$?Y80``M/`#`:H``A_6P`-?UL```+````*1P0``L"$``I$A``#+
M(OQ_TT$,@8LA_$&3P0``M,(``)!"_$?Y8@``M/`#`JH``A_6P`-?UA\@`]7]
M>[ZI_0,`D?,+`/G3``"P8`)".4`!`#7```"0`,Q'^8```+3```"P``1`^6G^
M_Y?8__^7(`"`4F`"`CGS"T#Y_7O"J,`#7]8?(`/5'R`#U=S__Q<?(`/5'R`#
MU1\@`]7]>[RI_0,`D?-3`:F@!@"T]V,#J?<#`*K```"0`/A'^1@`0/DX!@"T
M]5L"J?8#`:H5`(!2X`)`.1_T`'$$&$!ZP0(`5!,#0/G3`0"TM7Y`D_0#&*H?
M(`/5X@,5JN$#%ZK@`Q.J;_[_EX```#5@:G4X'_0`<0`"`%23CD#X\_[_M?5;
M0JGW8T.IX`,3JO-30:G]>\2HP`-?UO4#%ZJ@'D`X'_0`<0080'JA__]4M0(7
M2^7__Q>4`AC+M08`D7,"%8N4_D.3U`(`N>`#$ZKS4T&I]5M"J?=C0ZG]>\2H
MP`-?UA,`@-+I__\7$P"`TO=C0ZGF__\7_7NSJ<$``)#]`P"1(>1'^2(`0/GB
M9P#Y`@"`TL```+3S4P&I\P,`J@$`0#EA`0`U\U-!J<```)``Y$?YX6=`^0(`
M0/DA``+K`@"`TB$)`%3]>\VHP`-?UA'^_Y?T`P"J@/[_M/=C`ZD7``#P^",!
MD?<"%9'U6P*IX`,4JIC^_Y=@!0"T`4Q`.15,`)$_N`!Q80``5*$&0#D!__\T
M`$Q`.1^X`'%`!0!4X`,3JN#]_Y?V`P"JX`,5JMW]_Y?``@`+``@`$0!\0),)
M_O^7Y0,5JN0#$ZKC`Q>J]0,`J@(`@)(A`(!2UOW_E^(#&*KA`Q6J``"`4MK]
M_Y<?!``QH```5.!;0+D`#!02'Q!`<<`"`%3@`Q6JHO[_E^`#%:IH_O^7X`,4
MJF[^_Y?@^O^UX`,4JB/^_Y?@`Q.J3?[_E_-30:GU6T*I]V-#J;O__Q>@!D`Y
M'[@`<:'Z_U2@"D`YX/C_--+__Q?@`Q6JIO__E^O__Q?S4P&I]5L"J?=C`ZD4
M_O^7_7NUJ<,``)#A`P"J_0,`D6/D1_GS"P#YXJ,`D?,#`*ID`$#YY%<`^00`
M@-(``(!2/_[_ER`"`#7A.T"Y`@"44B$,%!(_$$!Q)!!">J`!`%3!``"0(>1'
M^>)70/DC`$#Y0@`#ZP,`@-*!`0!4\PM`^?U[RZC``U_6``"`4O7__Q?@`Q.J
M00"`4@7^_Y<?``!QX!>?&N___Q?M_?^7_7N^J?T#`)'S"P#Y\P,`JH#]_Y<"
M!`#18@("BW\"`NNC``!4,```%$($`-%_`@+K``(`5$``0#D?O`!Q8/__5'\"
M`NL"!0!40@0`T7\"`NL``0!4'R`#U4``0#D?O`!QX`$`5$($`-%_`@+K8?__
M5&`"0#D?O`!QP`,`5/,+0/D```#P_7O"J``@%9'!_?\70`!`.1^\`'&!``!4
M0@0`T7\"`NMC__]40@`3RP``@-)!"`"1/P1`\0@!`%3```"P!*`"D4($`)'A
M`Q.JX`,$J@,`@M*#_?^7\PM`^?U[PJC``U_6?P("ZZ']_U3A__\7\PM`^0``
M`/#]>\*H`,`3D:3]_Q<,"H+2_V,LR\,``)#B_X'2_7L`J?T#`)%CY$?Y\U,!
MJ?0#`*KU6P*I]2,!D?8#`:KW&P#YX0,5JF``0/G@)PCY``"`T@```/``0!61
M0/W_EQ\``''M!0!4`P0`4<$``)`AV$?YHLIC.#<`0+F"`P`U0P0`-'-\0)/@
M`Q6JX@,3JN$%@%+F_?^7@`,`M.`#%RIW_?^7XP,3JN(#%:KA`Q2JY_W_E\``
M`)``Y$?YX2=(^0(`0/DA``+K`@"`TL$#`%0,"H+2_7M`J?-30:GU6T*I]QM`
M^?]C+(O``U_6XP,`*N$%@%+@`Q6J<WQ`D^(#$ZK+_?^7P/S_M>`#%RI<_?^7
MX@,6JN$#%*H]_?^7YO__%\```)``V$?Y%P!`N>`#%RI3_?^7X@,6JN$#%*HT
M_?^7W?__%U[]_Y<?(`/5_7NZJ<(``)#]`P"1\U,!J?,#`*KT`P&J]5L"J?=C
M`ZE"Y$?Y(`!`.4$`0/GA+P#Y`0"`TA_T`'&4%I2:X`,4JN3\_Y?V`P"JX5,!
MD>`#$ZJ8_O^70`@`M/4#`*K=_/^7WP(`Z^D&`%3W5X"YV```D/?R?=-@`D`Y
M'_0`<0080'I`#`!4XP,3JF(<0#A?]`!Q1!A`>J'__U1C`!/+8WQ`DQC[1_G`
M"@"1```#BQ8#0/GX_/^7P&HW^,`"`+3C5X"YX`,3J@(#0/D!%$`X0WAC^#_T
M`'$D&$!Z80``.<```%0"%$`X8AP`.%_T`'%$&$!Z@?__5*$'@%(``(#2810`
M.()J8#AB:"`X``0`D:+__S7```"0`.1'^>$O0/D"`$#Y(0`"ZP(`@-*A!P!4
M\U-!J?5;0JGW8T.I_7O&J,`#7]8!`(#2'R`#U8)J83BB:B$X(00`D:+__S7N
M__\7V```D/EK!*D`^T?Y&@!`^4`#0/D`!0"TX`,:JA4`@%(?(`/5`8Q`^.(#
M%2JU!@`1H?__M4`,`!$`?'V3P0``L"*(0+DB`@`U(@"`4B*(`+FY_/^7^0,`
MJH`#`+2W?GV3X0,:JN(#%ZI[_/^7`/M'^1D``/F@!@`1/]L@^/57`+GY:T2I
MI?__%^$#`*K@`QJJU?S_E_D#`*H!^T?Y(```^4`!`+2W?GV3\___%P,`@-*E
M__\7``*`TA4`@%+@__\7^6L$J=3\_Y?Y:T2INO__%Q\@`]7]>[ZI_0,`D?,+
M`/G3``"0<]I'^6`"0+FZ_/^78`)`N;C\_Y?"``"0(P``\`$``/!CH!"10M1'
M^2&`%9'U_/^78`)`N:_\_Y?S"T#Y!```\/U[PJB$0"*1XP,$J@(``+`!``#P
M0D`SD2$`%I$%`(!2!/W_%_U[OZG```"0_0,`D0#81_D``$"YGOS_E_U[P:C"
M``"0(P``\`$``/!"U$?Y8Z`0D2&`%9':_/\7'R`#U0P*A-+_8RS+P```D`$(
M@M+]>P"I_0,`D0#D1_GS4P&I\^,`D?43`/GU8R&+%`"`T@$`0/GA)Q#Y`0"`
MTEG\_Y?D`P`J!0``\`,``/"E8!:18X`6D2(`@M(A`(!2X`,3JBC\_Y?@`Q.J
MX0,5J@(`@M(P_/^7@`'X-_,#`*H`!``1`'Q`DTO\_Y?T`P"JP```M'-^0)/A
M`Q6JX@,3J@G\_Y>?:C,XP```D`#D1_GA)U#Y`@!`^2$``NL"`(#2`0$`5.`#
M%*H,"H32_7M`J?-30:GU$T#Y_V,LB\`#7]9M_/^7R/__%PP<@M+_8RS+P@``
MD/U[`*G]`P"10N1'^?-3`:GS`P&J]5L"J>%3`9'U`P"J0P!`^>-O"/D#`(#2
M````\`#`%I&K_?^7]`,`JN$%@%+@`Q6JJ_S_EV`"`+3A`Q6J````\```%Y'V
M_O^7X`,5JL$``)`AY$?YXF](^2,`0/E"``/K`P"`TL$,`%0,'(+2_7M`J?-3
M0:GU6T*I_V,LB\`#7];@`Q6J]V,#J=G[_Y<7``#P^`,`*N%"%Y'@`Q.JT/O_
ME_,#`*J`"@"T]F,#D?EK!*D:``#P&0``\%K#$Y$Y(Q61'R`#U6`"0#F`!@`T
MM```M.$#$ZK@`Q2J3?S_E^`$`#3@`Q.JPOO_EP($`%'C`P"J8,(BBV'*8C@_
MO`!Q(0$`5!\@`]7C`P(J0@0`41\``#E@PB*+8<IB.#^\`'%`__]4``<`$0,`
M`PM__#]Q#`,`5.0#$ZKF`Q6JY0,9J@,``/!C8!>1`@""TB$`@%+@`Q:JJ_O_
ME^)C`9'A`Q:J``"`4J_[_Y>@```UX&M`N0`,%!(?($!Q8`(`5.%"%Y$``(#2
ME_O_E_,#`*K@^?^U]V-#J?EK1*FI__\7E```M(`"0#D?N`!Q@```5/,#&JHC
M`(!2W/__%X`&0#D`_O\T^___%^`#%JHA`(!2!?S_EV#]_S7A`Q:J````\```
M%Y&0_O^7X`,6JN+[_Y?W8T.I^6M$J9?__Q?W8T.ID/__%_=C`ZGY:P2IXOO_
MEQ\@`]4"`$`YX0,`JN(``#0?(`/5(00`D5^\`'$`$(&:(@!`.8+__S7``U_6
M'R`#U1\@`]6```"T`0!`.4$``#3E_?\7````\`#`$Y'&^_\7'R`#U?U[MZG"
M``"0(0``\/T#`)%"Y$?Y(:`0D?-3`:D4``#P\W,!D?5;`JG5``"0E((7D?=C
M`ZGY(P#YM?I'^48`0/GF1P#Y!@"`TB8<0:GF'P:I)!1"J>07!ZDA8$!YX0,!
M>>$#$ZK@`Q2J`OW_E^`!`+2B`D#YXU^`N4`,`XL!!$#Y07@C^.'^_[0!"$#Y
M`00`^0`@`)&A__^UX0,3JN`#%*KT_/^78/[_M=4``)`4``#PE,(7D;7Z1_GA
M`Q.JX`,4JNS\_Y?@`0"TH@)`^>-?@+E`#`.+`01`^4%X(_CA_O^T`0A`^0$$
M`/D`(`"1H?__M>$#$ZK@`Q2JWOS_EV#^_[75``"0%```\)3B%Y&U^D?YX0,3
MJN`#%*K6_/^7X`$`M*("0/GC7X"Y0`P#BP$$0/E!>"/XX?[_M`$(0/D!!`#Y
M`"``D:'__[7A`Q.JX`,4JLC\_Y=@_O^UU0``D!0``/"4(AB1M?I'^>$#$ZK@
M`Q2JP/S_E^`!`+2B`D#YXU^`N4`,`XL!!$#Y07@C^.'^_[0!"$#Y`00`^0`@
M`)&A__^UX0,3JN`#%*JR_/^78/[_M;4``/`4``#0ED(8D;7Z1_GA`Q.JX`,6
MJJK\_Y?@`0"TH@)`^>-?@+E`#`.+`01`^4%X(_CA_O^T`0A`^0$$`/D`(`"1
MH?__M>$#$ZK@`Q:JG/S_EV#^_[6V``#P%0``T+6"&)'6^D?YX0,3JN`#%:J4
M_/^7X`$`M,("0/GC7X"Y0`P#BP$$0/E!>"/XX?[_M`$(0/D!!`#Y`"``D:'_
M_[7A`Q.JX`,5JH;\_Y=@_O^UM@``\!4``-"WPA:1UOI'^>$#$ZK@`Q>J?OS_
ME^`!`+3"`D#YXU^`N4`,`XL!!$#Y07@C^.'^_[0!"$#Y`00`^0`@`)&A__^U
MX0,3JN`#%ZIP_/^78/[_M;<``/`6``#0V,(8D??Z1_GA`Q.JX`,8JFC\_Y?@
M`0"TX@)`^>-?@+E`#`.+`01`^4%X(_CA_O^T`0A`^0$$`/D`(`"1H?__M>$#
M$ZK@`QBJ6OS_EV#^_[6X``#P%P``T/D"&9$8^T?YX0,3JN`#&:I2_/^7X`$`
MM`(#0/GC7X"Y0`P#BP$$0/E!>"/XX?[_M`$(0/D!!`#Y`"``D:'__[7A`Q.J
MX`,9JD3\_Y=@_O^UN0``\!@``-`80QF1.?M'^>$#$ZK@`QBJ//S_E^`!`+0B
M`T#YXU^`N4`,`XL!!$#Y07@C^.'^_[0!"$#Y`00`^0`@`)&A__^UX0,3JN`#
M&*HN_/^78/[_M;D``/`8``#0&`,7D3G[1_GA`Q.JX`,8JB;\_Y?@`0"T(@-`
M^>-?@+E`#`.+`01`^4%X(_CA_O^T`0A`^0$$`/D`(`"1H?__M>$#$ZK@`QBJ
M&/S_EV#^_[7A`Q.J````T`"`&9$3_/^7X0,`JF```+3@`AF18_W_E^$#$ZH`
M``#0`.`9D0O\_Y?A`P"J@```M````-``X!.16OW_E^$#$ZH```#0`$`:D0+\
M_Y?A`P"J@`(`M*#"%I%2_?^7@$(8D0$``-`A(!N13OW_EZ```/``Y$?YX4=`
M^0(`0/DA``+K`@"`TN$#`%3S4T&I]5M"J?=C0ZGY(T#Y_7O)J,`#7];A`Q.J
M````T`"`&I'I^_^7X0,`JH```+3`PAB1.?W_E^?__Q<!*HC2XA-'^$'JJ_)A
MB,GRH2CH\E\``>L!_/]4X9-'>,"IAU(_``!K@?O_5,#"&)'A[P&1*OW_E]C_
M_Q>$^O^7_7N]J:$``/#]`P"1(>1'^?,+`/G3``"0(@!`^>(7`/D"`(#28!)`
MN1\$`#%@`0!4H0``\"'D1_GB%T#Y(P!`^4(``^L#`(#2(0(`5/,+0/G]>\.H
MP`-?UN&3`)$```#0`,`8D;K[_Y?A`P"J``"`4J$``+0@`$`Y'\``<0080'K@
M!Y\:8!(`N>K__Q=@^O^7_7N_J?T#`)$-^O^7@/K_ET```+0``$#Y_7O!J,`#
M7];]>[RIH@``\/T#`)%"Y$?Y\U,!J>'3`)'U6P*I%0``T+9"&Y%#`$#YXQ\`
M^0,`@-+T`P"JX`,6JIG[_Y>```"T`0!`.?,#`*K!`0`UH```\`#D1_GA'T#Y
M`@!`^2$``NL"`(#2(08`5.$#%*J@0AN1\U-!J?5;0JG]>\2HW/S_%^$#%*JB
M^O^7@`$`M*```/``Y$?YX1]`^0(`0/DA``+K`@"`TB$$`%3S4T&I]5M"J?U[
MQ*C``U_6X`,4JL#Y_Y?U`P"JX`,3JKWY_Y>@`@"+``@`D>KY_Y?F`Q.J`@"`
MDB$`@%+D`Q2J\P,`J@4``-`#``#0I4`7D6-@%Y&T^?^7H@``\$+D1_G@'T#Y
M00!`^0```>L!`(#2@0``5.$#$ZK@`Q:JT___%PWZ_Y<,-I#2_V,LRZ$``/#]
M>P&I_4,`D2'D1_GW8P2IUP``D.)"`)'S4P*I]/,!D?5;`ZGV`P"JX"-`D28`
M0/D&U`#Y!@"`TA@``-!$E$"IY!<(J>$#%*I*+$*I`,,6D4@D0ZGJ+PNI1AQ$
MJ>@G#*E$%$6IY)<)J4P,0/GL2P#Y0C!`^>)7`/GF'PVI.OO_EX```+0!`$`Y
M\P,`JB$A`#7Y:P6I^W,&J9/Y_Y<&^O^70!P`M!D`0/D9'`"TX`,9JG7Y_Y<`
M^'_3``0`D:+Y_Y<D`T`Y]0,`JJ0!`#0:``#0\P,5JEJC&Y$?(`/5X`,3JN,#
M&JH"`("2(0"`4FKY_Y=S"@"1)!]`."3__S4!``#0^>,"D2#@$Y$#```4((=`
M^,`)`+3A`Q2J$_O_E_,#`*I@__^T`0!`.2'__S2K^_^7X/[_-.`#$ZJS^?^7
M\P,`JD`(`+3@`Q.J3_G_E_H#`*K@`Q6J3/G_EUH#``M:$Q`1&0``T%I_0)/@
M`QJJ=OG_E^<#%:KD`Q.J)2,5D08``-`#``#0QL`;D6/@&Y$"`("2^P,`JB$`
M@%(_^?^7X`,;J@$X@%(8^O^7'P0`,:$``%0-^O^7!0!`N;]$`'%!%@!4XH,#
MD>$#&ZH``(!2SOG_E_,#`"H`!@`TH```\`(``-##`D#YY`,;J@#01_E"(!V1
M(0"`4A4`@-(``$#YIOG_EZ```/#A(T"1`.1'^2+40/D#`$#Y0@`#ZP,`@-(!
M*`!4X`,5J@PVD-+]>T&I\U-"J?5;0ZGW8T2I^6M%J?MS1JG_8RR+P`-?UOH#
M`I$9`(!2'R`#U5/;>?BS`0"T8`)`.6`!`#0Y!P`1X`,3JEO[_Y<@__\TX`,3
MJF/Y_Y?S`P"J(/;_M5/;>?BS_O^U$P"`TJW__Q?@\T"Y``P4$A\00''!^?]4
M]?M`N0_Y_Y>_`@!K0?G_5.#S0+D`(``2'P`'<<'X_U3@`QJJ'_G_EP$``-#U
M`P"J((`>D>$#%*JB^O^7H!``M-H"0/E'^?^7X0,`JN`#&JKA_/^7_`,`JL`/
M`+3@`QRJX/C_E_H#`*H?#`!Q[0$`5`!\0),!``#0`!``T2&@'I&``P"+7_G_
MEP`!`#5?$P!Q@!D`5%H7`%&`RWHX'[P`<0`9`%0?(`/5X!)`N1\$`#%`#0!4
M%```T$`.`#2`PAB1`0``T"$@&Y'2^_^7.2,5D10``-"40B*1%@``T.WX_Y?6
M8A^1Y@,`*N<#%*KE`QFJY`,;JN`#%:H#``#0`@"`DF,@'Y$A`(!2NOC_EQ$`
M`!2,^?^7``!`N1]$`'%!`@!4W/C_E_0#`/ES!@`1Y@,`*N<#$RKE`QFJY`,;
MJN,#%JK@`Q6J`@"`DB$`@%*I^/^7X`,5J@$X@%*"^?^7'P0`,8#]_U3@`QNJ
M0OG_E^$#%:H`PQ:1I_O_E^`#%:JJ_O^7=___%_5C`I$3`(!2'R`#U:#:<_B`
M`0"TX0,4JG,&`!%(^O^78/__M`$`0#DA__\T[/C_E_D#`*J`XO^UH-IS^,#^
M_[6@`8#2MOC_EQD``-#U`P"J.8,;D60*@%(3__\7H```\.0#&ZK#`D#Y`@``
MT`#01_E"(!R1(0"`4A4`@-(``$#Y^_C_EU7__Q>&_O^7H```\.$C0)$`Y$?Y
M(M1`^0,`0/E"``/K`P"`TH$2`%3@`Q.J##:0TOU[0:GS4T*I]5M#J?=C1*G_
M8RR+Q?C_%]P"0/F"__\7X0,4JA0``-"`PAB1%_K_EZ```+0``$`Y'\``<008
M0'KA"0!4_Q(`N>`#'*H!`(!2%```T!WY_Y?V`P`J0/'_-$(`@%(A`H"2\Z,&
MD9_X_Y?A`Q.JX`,6*L(`@-(+^?^7X*-&.8```#7@IT8Y'PP!<8`)`%0"`(!2
M`0"`TN`#%BJ2^/^7?@4`E/0#`*H%```4X@,`*N$#$ZK@`Q2JCP4`E.$#$ZK@
M`Q8J`@"0TO?X_Y<?``!Q[/[_5.`#%BKS@P61GOC_E_SC!9'A`Q2J&@``T/8#
M$ZKT`QRJEZ,`D5JC&Y'@`Q.JQ04`E,060#C@`Q2JXP,:JI0*`)$"`("2(0"`
M4B;X_Y?_`A3K`?__5.8#'*HE(Q61Y`,;J@<``-`#``#0YT`BD6/@'I$"`("2
M(0"`4N`#%:K_@P8Y&/C_E^`#&ZJV^/^7X0,5J@##%I$;^_^7X`,5JA[^_Y?K
M_O\7(`"`4N`2`+E`__\7U@9`^3;G_[3@`Q:J!?C_EQ\,`/&IYO]4`!``T0$`
M`-#``@"+(<`>D8;X_Y<?``!QG!.6FBW__Q?@JT8Y'P0!<6'V_U3@KT8Y'PP!
M<0'V_U3@LT8Y'R`!<:'U_U3@MT8Y'Q0!<4'U_U3@`Q8J0@"`4B$'@)([^/^7
MX0,3JN`#%BHB!8#2I_C_E^8#$ZHE(Q61Y`,;JN`#%:H'``#0`P``T.=`(I%C
MX!Z1`@"`DB$`@%+@]_^7//__%T+X_Y?Y:P6I^W,&J3_X_Y<?(`/5'R`#U?U[
MNZFA``#P_0,`D?-3`:FS``#P]5L"J?83`9%UVD?Y]V,#J2'D1_F@`D"Y(@!`
M^>(G`/D"`(#2'OC_E_0#`*J@`D"Y&_C_E^(#`*J#XD(Y````T.$#%JH`0!B1
M0^0".73Y_Y>```"T`0!`.3_$`'&`"P!44_S_EW7:1_F@`D"Y#/C_EP$``-!C
M`(!2(<`?D2(`@%(?^/^7]`,`JH`!`+2@`D"Y`_C_EX$*0/D"``#00N`?D2$`
M0/GB]_^7@`I`^0``0/D`#$"Y(`NP-W?:1_G5``"0X`)`N?;W_Y<!``#08P"`
M4B$`()$B`(!2"?C_E_0#`*J@`0"TX0,6J@```-```!>12_G_E_@#`*K@`D"Y
M^`<`M.?W_Y>!"D#YX@,8JB$`0/G']_^7<]I'^;<B`I%@`D"YW_?_E_0#`*I@
M`D"YW/?_ER(`@%(!``#0(2`@D13X_Y<"``#0X0,`JD*`()'@`Q2JM_?_EV`"
M0+G1]_^7X@,`JN$#%JH```#0`,`6D5_D`CDK^?^7X`H`^?,#`*K@`@"T`3B`
M4N`#$ZI-^/^7`00`$3\$`'$$B%%ZX00`5*```/``Y$?YX2=`^0(`0/DA``+K
M`@"`TN$#`%3S4T&I]5M"J?=C0ZG]>\6HP`-?U@`$0#F@]/\TH___%^`&0/FT
M_?^7X`H`^?,#`*K`_/^U````T`"@()'J]_^7J??_EZ`B`I&""D#Y`01`^4``
M0/DA`$#Y"/K_E\#__Q>@`D"YH/?_EX$*0/DA`$#Y]??_EZ/__Q>K]_^7M2("
MD>,#`"KB`Q.J````T`!`(9&A!D#Y(0!`^=/W_Y<?(`/5'R`#U?U[O*FA``#P
M_0,`D2'D1_GS4P&I]`,`JO5;`JDB`$#YXA\`^0(`@-+`!@"T`0!`.8$&`#2G
M^?^7`0!`.?,#`*KA```T'R`#U0`$`)$_O`!Q<Q*`F@$`0#F!__\UU@``D)\"
M`/'U!Y\:P!)`N1\$`#$`!0!4'P``<>`'GQJU`@`*E0$`-:```/``Y$?YX1]`
M^0(`0/DA``+K`@"`TH$%`%3S4T&I]5M"J?U[Q*C``U_6@`)`.8#^_S0!``#0
MX`,3JB'`&Y&"`(#21O?_E\#]_S6@``#0`.1'^>$?0/D"`$#Y(0`"ZP(`@-(A
M`P!4X`,4JO-30:GU6T*I_7O$J.[X_Q<```"P`,`3D5;W_Y?+__\7````L.'3
M`)$`P!B1J?C_EZ```+0``$`Y'\``<0080'IA``!4WQ(`N=/__Q<@`(!2P!(`
MN17Z_S3:__\73??_E_^#"M&A``#0XF,`D07@`)$(X`&1Y`,"JOU[`*G]`P"1
M(>1'^2,`0/GC3P'Y`P"`TJ$`0+F$0`"1HX1`^"$(P%J!`!_X8?Q@TV?\:-/G
M''B2)MQXTR$<"%/&''"2X^!#JB$`!JHA``.J@8`?^!\!!>L!_O]410`(D4$`
M0/E"(`"10P1`^40<0/EC``'*03!`^2$`!,HA``/*(_Q?TV$$`:HA?$"203P`
M^5\`!>MA_O]4!RA`J20SC](()$&I1%"K\N6;0:DC=)W2XOQ;T^S\0M-"%`>J
MC'D'JB$!",HCVZWR(0`*BB$`"<JE``2+(D`BBT']0M,A>`JJ0@`%BPL00/DM
M?$"2I0$(RL8`!(M"``L+I0`'BJ4`",HA``S*3OQ;TT_\0M.E``F+SA4"JJ4`
M!HLA``**XGD"JJ4`#@OFOT*I(0`-RJ[\6],A``B+SA4%JK#\0M/&``2+[P$$
MBR$`!HN&`0+*(0`."XQ]0)+&``6*Q@`,RB[\6]/&``V+SA4!J@UZ!:K&``^+
MQ@`."T4`#<KN'T#Y0GQ`DJ4``8HP_$+3I0`"RLX!!(NE``R+S_Q;TPQZ`:KO
M%0:JH0$,RJ4`#HON(T#YI0`/"ZU]0)(A``:*(0`-RL_\0M/F>0:J(0`"B\(!
M!(NN_%O3(0`"BZ_\0M."`0;*SA4%JBX`#@M"``6*Y7D%JHQ]0)+AOT2I0@`,
MRD(`#8O-_5O3K14.JM!\0)(A``2+0@`!B\$`!<I-``T+(0`.BB$`$,K&_4+3
MX@$$B\YX#JHA``R+K_U;TZ9\0)(A``*+[Q4-JJ(`#LJE_4+3+P`/"Z5X#:I"
M``V*X;=%J4(`!LI"`!"+[/U;TXP5#ZKP_4+3(0`$BT(``8O!`07*(0`/BLY]
M0)(A``[*3``,"P]Z#ZJB`02+(0`&BXW]6],A``*+H@`/RD(`#(JE?$"20@`%
MRJT5#*I"``Z++0`-"_"[1JF&_4+3QG@,JJ']6],L%`VJX0$&RB$`#8KO?4"2
M(0`/RA`"!(LA``6+0@`0B[#]0M-,``P+#7H-JL(!!(LA``*+P@`-RD(`#(K&
M?$"20@`&RH[]6]-"``^+SA4,JO"_1ZDN``X+A?U"TZ5X#*K!_5O3+!0.JJ$!
M!<HA``Z*K7U`DA`"!(LA``W*0@`0B]#]0M-,``P+#GH.JN(!!(LA``:+(0`"
MBZ(`#LI"``R*I7Q`DD(`!<J/_5O30@`-B^\5#*KPMTBI+P`/"X;]0M/&>`RJ
MX?U;TRP4#ZK!`0;*(0`/BLY]0)(0`@2+(0`.RD(`$(OP_4+33``,"P]Z#ZJB
M`02+(0`%BR$``HO"``_*0@`,BL9\0))"``;*C?U;TT(`#HNM%0RJ\+M)J2T`
M#0N%_4+3I7@,JJ']6],L%`VJX0$%RB$`#8KO?4"2$`($BR$`#\I"`!"+L/U"
MTTP`#`L->@VJP@$$BR$`!HLA``*+H@`-RH[]6].E?$"20@`,BLX5#*I"``7*
M+@`."T(`#XN&_4+3X;]*J<QX#*K&_5O3QA0.JB$`!(OD`02+0@`!BZ$!#,HA
M``Z*K7U`DB$`#<K/_4+3T@`""^YY#JHA``6+0D`FB^]?0/DA``2+A`$.RD7^
M6].$``)*I102JN(!`XN$``V+3?Y"T[```0NR>1*JA``"B^)C0/DA0"6+Q0$2
MR@;^6].E``%*QA00JD$``XL-_D+3HD`LB\\`!`NM>1"J0@`!B^%G0/F$0":+
M1@(-RN7]6]/$``1*I10/JB8``XN!0"Z+L0`""R$`!HOL_4+30D`EB^9K0/F/
M>0^JI0$/RB3^6].$%!&JI0`"2L(``XLF_D+3D``!"]%X$:KF;T#Y(4`DB^0!
M$<JL0#*+A``!2@7^6].E%!"J@@$"B\$``XL,_D+3AD`MBZX``@N0>1"JP0`!
MB^9S0/E"0"6+)0(0RL3]6].B``)*A!0.JL8``XM"0"^+S/U"TXT``0N.>0ZJ
M0@`&B^9W0/DA0"2+!`(.RJ7]6].!``%*I10-JL8``XLA0#&+KP`""R$`!HNL
M_4+30D`EB^9[0/F->0VJQ0$-RN3]6].$%`^JI0`"2L(``XOF_4+3D0`!"\]X
M#ZKF?T#Y(4`DBZ0!#\JL0#"+A``!2B7^6].E%!&J@@$"B\$``XLL_D+3AD`N
MB[```@N,>1&JP0`!B^:#0/E"0"6+Y0$,R@3^6].B``)*A!00JL8``XM"0"V+
M#?Y"TXX``0M"``:+IGD0JO"'0/DA0"2+A`$&RL7]6].!``%*I10.JA`"`XLA
M0"^+K0`""R$`$(O/_4+30D`EB_"+0/GN>0ZJQ0`.RJ3]6].$%`VJI0`"2@("
M`XNP_4+3CP`!"PUZ#:KPCT#Y(4`DB\0!#<JL0"R+A``!2N7]6].E%`^JAD`F
MBP$"`XN"`0*+\/U"TZP``@O!``&+!GH/JO"30/E"0"6+I0$&RH3]6].B``)*
MA!0,JA`"`XM"0"Z+COU"TX\``0O,>0RJ0@`0B_"70/DA0"2+Q``,RN7]6].!
M``%*I10/JA`"`XLA0"V+[?U"TZX``@NO>0^J(0`0B_";0/E"0"6+A0$/RL3]
M6].B``)*A!0.JD)`)HL%`@.+T/U"TXT``0M%``6+`GH.JO"?0/DA0"2+Y`$"
MRJ;]6].$``%*QA0-J@$"`XN$0"R+L/U"TX0``8L!>@VJS@`%"Z5`)HM&``'*
MQ0`%2LS]6].E0"^+S_U"TXP5#JKN>0ZJ\#]4J8T!!`N$0"R+IOU;T\84#:H0
M`@.+I0`0BS``#LK,``4+$`($2@)"(HOD`0.+L/U"TX_]6],->@VJ[Q4,JD(`
M!(NE0":+Y*M`^4(`#PO&`0W*Q0`%2H,``XN&_4+3H4`ABT3\6]/,>`RJA!0"
MJB$``XLA``0+HP$,JN2O0/F%`0T*8P`"BD_\0M-C``6JAIN7TF;CL?+B>0*J
MA``&BV-`+HLE_%O3+OQ"TZ44`:IC``2+A`$"JF,`!0N$``&*P7D!JN4[5JE/
M``P*A``/JF_\0M.$0"V+;?Q;TZT5`ZJE``:+S@$&BX0`!8M%``&JA``-"Z4`
M`XHM``(*I0`-JHW\6].E0"R+['D#JJ4`#HNC%02J+0`,JJ,``PONNT#YI0$$
MBHT!`0J/_$+3I0`-JLX!!HNE0"*+;?Q;T^)Y!*JM%0.JA`$"JJ4`#HONOT#Y
MI0`-"X0``XI-``P*A``-JF_\0M/.`0:+A$`ABZW\6]/A>0.JK14%JH0`#HN$
M``T+0P`!JNW#0/DN``(*8P`%BJ_\0M-C``ZJY7D%JJT!!HMC0"R+COQ;TRP`
M!:K.%02J8P`-B^W'0/EC``X+C`$$BJX``0J,`0ZJCOQ"TX)!(HNL`0:+;?Q;
MT\1Y!*JM%0.J0@`,BT(`#0NL``2J[<M`^8X`!0J,`0.*;_Q"TXP!#JKC>0.J
MK0$&BX%!(8M._%O3C``#JLX5`JHA``V+(0`."XP!`HIN``0*C`$.JD[\0M/"
M>0*JA4$EB^V[6:DO_$+3K`$&BRW\6].M%0&JI0`,BVP``JJE``T+C`$!BDT`
M`PJ,`0VJX7D!JLX!!HN$022+K?Q;TTP``:JM%06JA``.B^[70/F$``T+C`$%
MBBT``@J,`0VJK_Q"T\X!!HN#02.+C?Q;T^QY!:JM%02J)0`,JF,`#HNE``2*
M[MM`^6,`#0N-`0$*C_Q"TZ4`#:KD>02JS@$&BZ)`(HMM_%O3A0$$JJT5`ZI"
M``Z+[M]`^4(`#0NE``.*C0`,"F_\0M.E``VJS@$&BZ%`(8M-_%O3Y7D#JJT5
M`JJ#``6J(0`.BT[\0M,A``T+8P`"BL)Y`JJO``0*[3M<J6,`#ZIL0"R+(_Q;
MTV,4`:HO_$+3K0$&BXP!#8NM``*J@P$#"ZP!`8I-``4*X7D!JHP!#:IM_%O3
MA$$DB\P!!HN$``R+3``!JBX``@J,`0.*C`$.JJT5`ZJ%026+A``-"^\S7:EM
M_$+3K7D#JH[\6]/.%02J[P$&BZ,`#XLE``VJ8P`."Z4`!(JN`0$*I0`.JH[\
M0M/$>02JHD`BBX4!!HML_%O3C!4#JD(`!8MN_$+3I0$$JD(`#`NE``.*PWD#
MJH\`#0KL.UZII0`/JJ5`(8M!_%O3(10"JD_\0M.,`0:+I0`,BXP``ZJE``$+
MC`$"BF$`!`KB>0*JC`$!JE```PJ!02V+S0$&BZS\6],A``V+C!4%JFT``JKO
M^T#YC@$!"ZT!!8HL0"R+K0$0JM#]0M.D022+[0$&BZ_\0M/&_5O3QA0.JH0`
M#8OM>06JT@`$"^__0/E!``W*(0`,2L4ZF-)%3+GR(4`CB^P!!8M#_EO3#GH.
MJF,4$JHA``R+A$`FB^P#0?EQ``$+I@$.RB%`(XO$``1*A@$%BX)`(HM,_D+3
M)/Y;TY)Y$JJ$%!&J0@`&B^P'0?F0``(+PP$2RB;^0M-C``%*@0$%BVQ`+8L#
M_EO3T7@1JHP!`8MC%!"J0D`DB^8+0?EO``P+1`(1RH-!(XN$``)*X?U;T\(`
M!8N&0"Z+!/Y"T\8``HN0>!"J(10/JN0/0?DN``8+(@(0RNS]0M-"``-*@P`%
MBT1`,HO"_5O3CWD/JH0``XM"%`ZJP4`AB^,30?E-``0+!@(/RLS]0M/!``%*
M9@`%BR-`,8NA_5O3CGD.JF,`!HLA%`VJ[`$.RN870?DR``,+@D`BBV%`(8N"
M`0)*Q``%BTQ`,(NF_4+30OY;T\UX#:J$`02+0A02JN8;0?E1``0+PP$-RDS^
M0M-A``%*PP`%BR9`+XLA_EO3PP`#BXQY$JHA%!&J@D`BB^8?0?DP``,+I`$,
MRF%`(8N"``)*Q@`%BT1`+HLN_D+3`OY;TX0`!HM"%!"JQGD1JNXC0?E/``0+
M@P$&RH)`(HMA``%*S@$%BR-`+8L-_D+3X?U;T[!Y$*IC``Z+(10/JNXG0?DM
M``,+Q``0RF%`(8N"``)*Q`$%BTQ`+(ON_4+3HOU;T\]Y#ZJ$`02+0A0-JNPK
M0?E.``0+`P(/RH)`(HMA``%*@P$%BR9`)HNL_4+3P?U;T\,``XLA%`ZJAGD-
MJNPO0?DM``,+Y`$&RF%`(8N"``)*C`$%BT1`,(O0_4+3HOU;TPYZ#JJ$``R+
M0A0-JNPS0?E1``0+PP`.RH)`(HMA``%*C`$%BR-`+XNO_4+3(?Y;T^UY#:IC
M``R+(101JNPW0?DP``,+Q`$-RB_^0M."``)*A`$%BTQ`)HL"_EO3A@$$BT(4
M$*KL>1&J84`AB^0[0?E/``8+HP$,RL)`(HMA``%*@P`%BR1`+HL._D+3X?U;
MTX0``XLA%`^JPWD0JO`_0?DN``0+A@$#RH%`(8O"``)*$`(%BT9`+8OM_4+3
MPOU;TZ]Y#ZI"%`ZJQ@`0B^U#0?E0``8+9``/RL)`(HN$``%*H0$%BXQ`+(O-
M_4+3!/Y;TXP!`8NN>0ZJA!00JN%'0?F1``P+Y@$.RN=`+XO&``)*(@`%B\-`
M(XLA_EO38P`"BR$4$:IC``$+`?Y"T^U+0?DA>!"JAD$DB\(!`<ID_%O3K```
ML$8`!DJ$%`.JI0$%BR+^0M.$``:+I0`'BX;E1_E">!&J(0`)"\L!"PMC``H+
MA``%"T@`"`L$#`"I"`0!J0L0`/G@3T'YP0!`^0```>L!`(#2@0``5/U[0*G_
M@PJ1P`-?UBSS_Y?]>[^I`!"`TOT#`)'P\O^7'Q@`^29@A-(E<972Q)^;TL..
MBM("/IS2INBL\J7YO?)$%[/R0P:B\D)ZN/(&%`"I!`P!J0)\`JD?>`"Y_7O!
MJ,`#7]8?(`/5'R`#U?U[O*E"?$"3_0,`D?-3`:D4X`"1\P,!JO5;`JGU`P"J
M]@,"JO=C`ZD%C$*I`'A`N:0,`@N_``3K8Y2#FF)T0HNDB@*I(`0`-=_^`'$M
M!@!4U@(!4=A^!E,7!P`1]VIZTW<"%XL?(`/58`9`J8`&`*ES`@&18@Y]J8(.
M`:G@`Q6J8@Y^J8(.`JEB#G^I@@X#J:3[_Y=_`A?K@?[_5-8:&$OA`Q>JX`,4
MJL)^0)-U\O^7MGH`N?-30:GU6T*I]V-#J?U[Q*C``U_6%PB`4O<"`$O?`A=K
M@,(@B]?2EQKX?D"3X@,8JF?R_Y>@>D"YX`(`"Z!Z`+D?``%QX?W_5-8"%TMS
M`AB+X`,5JH;[_Y?/__\7]P,3JN/__Q<?(`/5'R`#U?U[O*G]`P"1\U,!J?,#
M`:KT`P"J]5L"J77B`)'A#X`2]QL`^6`60/EV*D"Y=S)`N0`@`U/6"L!:`@0`
M$?<*P%JARB`XH,(BBU_@`'&-"0!4`0B`4B(``DL!`(!20GQ`DY3R_Y?@`Q.J
M9OO_EW_^`ZE__@2I?_X%J7\V`/EW6@XIX`,3JE_[_Y=A`D#YX`,3JB'\6-.!
M`@`Y80)`^2'\4-.!!@`Y80)`^2'\2-.!"@`Y80)`^8$.`#EA!D#Y(?Q8TX$2
M`#EA!D#Y(?Q0TX$6`#EA!D#Y(?Q(TX$:`#EA!D#Y@1X`.6$*0/DA_%C3@2(`
M.6$*0/DA_%#3@28`.6$*0/DA_$C3@2H`.6$*0/F!+@`Y80Y`^2'\6-.!,@`Y
M80Y`^2'\4-.!-@`Y80Y`^2'\2-.!.@`Y80Y`^8$^`#EA$D#Y(?Q8TX%"`#EA
M$D#Y(?Q0TX%&`#EA$D#Y(?Q(TX%*`#EA$D#Y@4X`.?-30:GU6T*I]QM`^?U[
MQ*BJ\O\7`0>`4B(``DL!`(!20GQ`DTGR_Y>[__\7'R`#U1\@`]4?(`/5_7N\
MJ?T#`)'S4P&IM```L)2"+9'U6P*IM0``L+5B+9&4`A7+]@,`*O=C`ZGW`P&J
M^`,"JI3^0Y/4\?^7=`$`M!,`@-(?(`/5HWIS^.(#&*IS!@"1X0,7JN`#%BI@
M`#_6GP(3ZR'__U3S4T&I]5M"J?=C0ZG]>\2HP`-?UA\@`]7``U_6'R`#U1\@
M`]4?(`/5HP``T&,$0/GV\?\7_7N_J?T#`)']>\&HP`-?U@`````!``(`````
M`"]T;7``````+@````````!005)?5$U01$E2````````5$U01$E2``!414U0
M1$E2`%1%35``````5$U0``````!54T52`````%5315).04U%```````````E
M<R\E<P```"\`````````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O
M;W1?1'EN84QO861E<@``````26YT97)N86QS.CI005(Z.D)/3U0`````97AE
M```````O<')O8R\E:2\E<P``````4$%27U1%35```````````%!!4E]04D]'
M3D%-10`````Z`````````"5S)7,E<P``4$523#5,24(``````````%!%4DQ,
M24(`4$523#5/4%0``````````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!
M4E]34$%73D5$``````!005)?0TQ%04X`````````4$%27T1%0E5'````````
M`%!!4E]#04-(10````````!005)?1TQ/0D%,7T1%0E5'``````````!005)?
M1TQ/0D%,7U1-4$1)4@````````!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!
M3%]#3$5!3@``````````4$%27T-,14%./0```````#$`````````3$1?3$E"
M4D%265]0051(`%-94U1%30``)3`R>`````!P87(M`````"5S)7,E<R5S````
M```````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@
M9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R:79A=&4@<W5B9&ER96-T
M;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@
M>6]U<B!O<&5R871I;VXI"@```````%!!5$@`````<&%R;``````N<&%R````
M`"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M
M)74E<P``````````&`````````!P97)L`````#``````````4$%2.CI086-K
M97(Z.E9%4E-)3TX`````,2XP-3(```!5;F%B;&4@=&\@8W)E871E(&-A8VAE
M(&1I<F5C=&]R>0``````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C
M:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``````````
M+64````````M+0```````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@
M)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@
M<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1P87)?
M=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$
M('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`[
M"G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*
M;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M
M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*
M1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@
M=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD
M("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N
M97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@
M)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^
M9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD
M>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@
M)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@
M7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*
M8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^
M+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W
M;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F
M:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4
M*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["B1005)?34%'
M24,@/2`B7&Y005(N<&U<;B(["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY
M("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A
M=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?
M97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO
M(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7
M:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S
M971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*
M;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/#IR
M87<G+"`D<')O9VYA;64@;W(@;&%S=#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M
M<R`D<')O9VYA;64["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D
M;6%G:6-?<&]S.PII9B`H)'-I>F4@/#T@)&-H=6YK7W-I>F4I('L*)&UA9VEC
M7W!O<R`](#`["GT@96QS:68@*"AM>2`D;2`]("1S:7IE("4@)&-H=6YK7W-I
M>F4I(#X@,"D@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D;3L*?2!E;'-E('L*
M)&UA9VEC7W!O<R`]("1S:7IE("T@)&-H=6YK7W-I>F4["GT*=VAI;&4@*"1M
M86=I8U]P;W,@/CT@,"D@>PIS965K(%]&2"P@)&UA9VEC7W!O<RP@,#L*<F5A
M9"!?1D@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I
M.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P
M*2!["B1M86=I8U]P;W,@*ST@)&D["FQA<W0["GT*)&UA9VEC7W!O<R`M/2`D
M8VAU;FM?<VEZ93L*?0IL87-T(&EF("1M86=I8U]P;W,@/"`P.PIS965K(%]&
M2"P@)&UA9VEC7W!O<R`M(#0L(#`["G)E860@7T9(+"`D8G5F+"`T.PIS965K
M(%]&2"P@)&UA9VEC7W!O<R`M(#0@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,#L*
M)&1A=&%?<&]S(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@
M7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A
M9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR
M96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L
M("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN
M9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M
M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D
M8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN
M*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@
M+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E
M7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F
M=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?
M5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8F%S96YA;64D
M97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I
M.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD36]D=6QE
M0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C
M+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*
M?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`
M7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF
M;R`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5](&]R(')E='5R;CL*
M)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H
M)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@
M>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG
M="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M
M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N
M("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O
M+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/#IR
M87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M
M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I
M;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@
M0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H
M:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I
M6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]
M?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*
M<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE
M<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L
M971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D
M8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@
M+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?
M87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I
M.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D55
M4T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE
M<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=6
M6S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?
M8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@
M('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD[
M"FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T
M($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*
M96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC
M.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I
M=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A
M9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S
M92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G
M<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS
M:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D
M,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G
M<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@
M)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL
M92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M
M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C
M;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I
M.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U
M;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%2
M1U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*
M:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI
M=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI
M9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@
M;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A
M<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD
M>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE
M2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*
M;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*
M?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP
M+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD
M+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ
M72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@
M;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A
M<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@
M-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B
M=68@97$@(E!+7#`P,UPP,#0B.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D
M;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE
M.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE
M.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F
M:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L
M(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1D871A7W!O<RD@>PIR96%D
M(%]&2"P@)&QO861E<BP@)&1A=&%?<&]S.PI](&5L<V4@>PIL;V-A;"`D+R`]
M('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"
M051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I
M<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*9F]R96%C:"!M>2`D:V5Y("AS
M;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT
M.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA
M9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T
M(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[
M)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D
M,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R
M*3L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?
M;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@
M>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF
M:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV
M;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I
M;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ
M9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]
M("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?
M97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H
M<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E
M9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI
M('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R
M96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%
M+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T
M.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF
M("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH
M)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*
M?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N
M>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O
M7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)
M3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL
M92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@
M/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P
M96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A
M9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1F:#X["F-L;W-E("1F:#L*
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB
M961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA
M;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#
M;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*
M?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@
M*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T
M94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C
M;VYT96YT*2DL"B1C;VYT96YT*3L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M
M92)=*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II
M<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII
M9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;
M.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96X@;7D@
M)&9H+"`B/#IR87<B+"`D;W5T.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E
M("1F:#L*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE
M7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C
M86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I
M.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO
M861E<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!1TE#*3L*)&9H+3YC;&]S93L*
M8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN
M960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL
M93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C
M:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P
M96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE
M9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM
M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&
M:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:
M7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B
M)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@
M,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A
M8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"
M54=].PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0
M?2)=*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@
M8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z
M:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD[
M"FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N
M;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG
M.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN
M86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*
M;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?
M5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M
M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q
M6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI
M<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A
M8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B72D["B1M96UB
M97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U
M-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE
M<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U
M;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@
M72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@
M6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@
M0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"
M87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ
M0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E
M($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S
M*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E
M<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D
M97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@
M=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E
M($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R
M.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q
M=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@
M6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4[
M"G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U
M:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE
M=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*
M979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E
M($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z
M.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[
M(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F
M."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R
M7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P
M("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0
M(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S
M<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY
M("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W
M=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z
M.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE
M.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U
M:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%
M3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G
M.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N
M<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P
M<F]G;F%M92DI6SE=*2!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA
M;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*<V5E
M:R`D9F@L("TQ."P@,CL*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(#8["FEF
M("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIR96%D
M("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@
M(B1#;VYF:6=[7V1E;&EM?6-A8VAE+21B=68B.PI]"F5L<V4@>PIM>2`D9&EG
M97-T(#T@979A;`I["G)E<75I<F4@1&EG97-T.CI32$$["FUY("1C='@@/2!$
M:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R
M;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T[
M"B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG
M97-T.PI]('Q\("1M=&EM93L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM
M?6-A8VAE+21D:6=E<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[
M4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT
M96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D
M<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U
M8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`
M7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H
M+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B
M.PIO<&5N(&UY("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE(&]R(&1I92!Q<5M#
M86XG="!W<FET92`B)'1E;7!N86UE(CH@)"%=.PIP<FEN="`D9F@@)&-O;G1E
M;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F
M:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U
M;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?
M<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345]
M(&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M
M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0
M?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@
M>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N
M86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]0
M4D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI
M(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR
M971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?
M97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*
M?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E
M<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?
M5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<
M421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II
M9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X
M97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@
M?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@
M)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D
M.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z
M.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P
M=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM
M?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345]
M(#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6
M>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92![
M"B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%
M1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T
M92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%
M04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/
M0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]
M"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@
M("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%2
M7T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%
M04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE
M;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU
M92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R
M;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN
M(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*
M<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@
M)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X
M<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R
M;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF
M="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G
M<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P
M<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S
M("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I
M9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`[
M"GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I
M9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D
M.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*``!P97)L>'-I
M+F,`````````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("``````
M`1L#.P@!```@````5(O__RP&``#4C?__(`$```2.__\T`0``1([__T@!``"4
MCO__;`$``*2.__^$`0``F(___^P!```8D?__3`(``+21__]T`@``N)+__Z@"
M``#TD___Y`(``"26__\X`P``F);__UP#``#4EO__?`,``+27__^P`P``N)?_
M_\0#``#DF?__,`0``!2:__]$!```-)K__U@$``!8G___E`0``.B?__^X!```
M"*#__]@$```TH?__%`4``'2H__^X!0``Y*K___`%```TK/__7`8``+B\__^`
M!@``%+W__Z`&```TOO__V`8``-2___\,!P``5,#__T`'``!DP/__5`<``!``
M`````````7I2``1X'@$;#!\`$````!@```"LC/__,``````````0````+```
M`,B,__\\`````````"````!`````](S__T@`````00X@G02>`T*3`D[>W=,.
M`````!0```!D````((W__P0``````````````&0```!\````&(W___0`````
M00Y`G0B>!T*3!I0%0I@!EP)&E@.5!%;6U4'8UT/>W=/4#@!!#D"3!I0%E026
M`Y<"F`&=")X'3];50=C70=[=T]0.`$$.0),&E`6=")X'0I<"F`%"V-<`7```
M`.0```"DC?__@`$```!!#M`!G1J>&4B4%Y,81-332-[=#@!!#M`!DQB4%YT:
MGAE$F!.7%$26%946<@K4TT'6U4'8UT$+2=/4U=;7V$&4%Y,80985E19!F!.7
M%```)````$0!``#$CO__G`````!!#K`!G1:>%463%%<*WMW3#@!!"P```#``
M``!L`0``.(___P0!````00X@G02>`T*3`E\*WMW3#@!""U0*WMW3#@!!"T;>
MW=,.```X````H`$```B0__\X`0```$(.T"!#G8H$GHD$0Y.(!)2'!$*5A@26
MA01#EX0$:0K=WM?5UM/4#@!!"P!0````W`$```B1__\L`@```$$.8)T,G@M#
MDPJ4"4R5")8'EP:8!7\*WMW7V-76T]0.`$$+29H#F01?"MK900M)V=I"F02:
M`T/9VD&:`YD$0MK9```@````,`(``.22__]T`````$$.()T$G@-"DP)2WMW3
M#@`````<````5`(``#23__\X`````$$.$)T"G@%&WMT.`````#````!T`@``
M4)/__^``````0@[00$.=B@B>B0A#DX@(E(<(0I6&"&P*W=[5T]0.`$$+```0
M````J`(``/R3__\$`````````&@```"\`@``[)/__R@"````0@[@(4*=G`2>
MFP1#DYH$E)D$0Y68!):7!%T*W=[5UM/4#@!!"T*8E027E@1*FI,$F90$>`K8
MUT':V4$+5=C70=K909>6!)B5!$'8UT*8E027E@1!FI,$F90$`!`````H`P``
MK)7__R@`````````$````#P#``#(E?__'``````````X````4`,``-25__\D
M!0```$$.D`&=$IX11I,0E`]#E0Z6#427#)@+F0H#(0$*WMW9U]C5UM/4#@!!
M"P`@````C`,``+R:__^0`````$$.,)T&G@5$DP10"M[=TPX`00L<````L`,`
M`"B;__\@`````$$.$)T"G@%&WMT.`````#@```#0`P``*)O__RP!````00Y`
MG0B>!T:3!I0%E026`U@*WMW5UM/4#@!!"TT*WMW5UM/4#@!!"P```*`````,
M!```&)S__S@'````0@ZP@P)"G;0@GK,@0Y>N()BM($.3LB"4L2!"E;`@EJ\@
M7)JK()FL($&<J2";JB`":0K:V4'<VT'=WM?8U=;3U`X`00L"FMG:V]Q0W=[7
MV-76T]0.`$$.L(,"D[(@E+$@E;`@EJ\@EZX@F*T@F:P@FJL@FZH@G*D@G;0@
MGK,@`HO9VMO<09JK()FL($&<J2";JB``-````+`$``"THO__:`(```!!#E"=
M"IX)0Y,(E`="E0:6!4.7!)@#`FX*WMW7V-76T]0.`$$+```X````Z`0``.RD
M__]0`0```$$.0)T(G@=$DP:4!4*5!)8#9`K>W=76T]0.`$$+4PK>W=76T]0.
M`$$+```L````)`4``""%__\H`@```$$.8)T,G@M%DPJ4"94(E@<"8@K>W=76
MT]0.`$$+```@````5`4``-"E__^$$````$$.H`5&G52>4P,8!`K=W@X`00L<
M````>`4``#"V__]4`````$$.$)T"G@%3WMT.`````#0```"8!0``;+;__Q@!
M````00Y`G0B>!T.3!I0%0Y4$E@-#EP*8`6<*WMW7V-76T]0.`$$+````,```
M`-`%``!4M___E`$```!!#D"=")X'0I,&E`5#E026`T.7`@)5"M[=U]76T]0.
M`$$+`#`````$!@``P+C__WP`````00Y`G0B>!T*3!I0%0Y4$E@-%EP*8`5/>
MW=?8U=;3U`X````0````.`8```RY__\$`````````!````!,!@``"+G__PP`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````/`B````````H"(`
M```````!`````````!$#`````````0`````````A`P````````$`````````
M,0,````````!`````````#L#````````#`````````"X&P````````T`````
M````S%0````````9`````````%BK`0``````&P`````````(`````````!H`
M````````8*L!```````<``````````@`````````]?[_;P````"8`@``````
M``4`````````>`T````````&`````````(@#````````"@````````#&!```
M``````L`````````&``````````5`````````````````````P````````"(
MK0$```````(`````````H`4````````4``````````<`````````%P``````
M```8%@````````<`````````>!,````````(`````````*`"````````"0``
M```````8`````````!X`````````"`````````#[__]O``````$```@`````
M_O__;P`````8$P```````/___V\``````P````````#P__]O`````#X2````
M````^?__;P`````0````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````T!L```````#0&P``
M`````-`;````````T!L```````#0&P```````-`;````````T!L```````#0
M&P```````-`;````````T!L```````#0&P```````-`;````````T!L`````
M``#0&P```````-`;````````T!L```````#0&P```````-`;````````T!L`
M``````#0&P```````-`;````````T!L```````#0&P```````-`;````````
MT!L```````#0&P```````-`;````````T!L```````#0&P```````-`;````
M````T!L```````#0&P```````-`;````````T!L```````#0&P```````-`;
M````````T!L```````#0&P```````-`;````````T!L```````#0&P``````
M`-`;````````T!L```````#0&P```````-`;````````T!L```````#0&P``
M`````-`;````````T!L```````#0&P```````-`;````````T!L```````#0
M&P```````-`;````````T!L```````#0&P```````-`;````````T!L`````
M``#0&P```````-`;````````:*L!``````"P5```````````````````````
M````````````````````````````````````````````````````````````
M```````````P5```````````````````L!\`````````````````````````
M``````````````````````````BP`0``````_____P````#H5````````/!4
M``````````````````#X5`````````A5````````$%4````````850``````
M`"!5```````````````````H50```````#!5``````````````````"H6```
M`````$=#0SH@*$1E8FEA;B`Q,"XR+C$M-BD@,3`N,BXQ(#(P,C$P,3$P```N
M<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N8G5I;&0M:60`+FYO=&4N04))
M+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N
M9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT
M`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?
M87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC
M;VUM96YT````````````````````````````````````````````````````
M````````````````````````````````````````````"P````$````"````
M`````#@"````````.`(````````;`````````````````````0``````````
M`````````!,````'`````@````````!4`@```````%0"````````)```````
M``````````````0````````````````````F````!P````(`````````>`(`
M``````!X`@```````"`````````````````````$````````````````````
M-````/;__V\"`````````)@"````````F`(```````#P``````````4`````
M````"````````````````````#X````+`````@````````"(`P```````(@#
M````````\`D````````&`````P````@`````````&`````````!&`````P``
M``(`````````>`T```````!X#0```````,8$```````````````````!````
M````````````````3@```/___V\"`````````#X2````````/A(```````#4
M``````````4``````````@`````````"`````````%L```#^__]O`@``````
M```8$P```````!@3````````8``````````&`````P````@`````````````
M``````!J````!`````(`````````>!,```````!X$P```````*`"````````
M!0`````````(`````````!@`````````=`````0```!"`````````!@6````
M````&!8```````"@!0````````4````5````"``````````8`````````'X`
M```!````!@````````"X&P```````+@;````````%```````````````````
M``0```````````````````!Y`````0````8`````````T!L```````#0&P``
M`````.`#```````````````````0````````````````````A`````$````&
M`````````+`?````````L!\````````<-0``````````````````$```````
M`````````````(H````!````!@````````#,5````````,Q4````````$```
M``````````````````0```````````````````"0`````0````(`````````
MX%0```````#@5````````'H_```````````````````(````````````````
M````F`````$````"`````````%R4````````7)0````````,`0``````````
M````````!````````````````````*8````!`````@````````!HE0``````
M`&B5````````8`8```````````````````@```````````````````"P````
M#@````,`````````6*L!``````!8JP````````@````````````````````(
M``````````@`````````O`````\````#`````````&"K`0``````8*L`````
M```(````````````````````"``````````(`````````,@````&`````P``
M``````!HJP$``````&BK````````(`(````````&``````````@`````````
M$`````````#1`````0````,`````````B*T!``````"(K0```````'@"````
M```````````````(``````````@`````````U@````$````#``````````"P
M`0```````+````````"`````````````````````"```````````````````
M`-P````(`````P````````"`L`$``````("P````````*!``````````````
M``````@```````````````````#A`````0```#````````````````````"`
ML````````"<````````````````````!``````````$``````````0````,`
M````````````````````````I[````````#J`````````````````````0``
-````````````````````
